@@ -41,10 +41,10 @@ def WriteConfig(self):
 #        config.write(configfile)
 
 
-def SetConfig_SearchSettings(self, SearchLoc, Specific=""):
-    if (SearchLoc==1):
-        self.core.SearchLoc = 1
-        self.core.imageDir = "/media/mmc1/DCIM/"
-    else:
-        self.core.SearchLoc = 0
-        self.core.imageDir = "/home/user/MyDocs/DCIM/"
+#def SetConfig_SearchSettings(self, SearchLoc, Specific=""):
+#    if (SearchLoc==1):
+#        self.core.SearchLoc = 1
+#        self.core.imageDir = "/media/mmc1/DCIM/"
+#    else:
+#        self.core.SearchLoc = 0
+#        self.core.imageDir = "/home/user/MyDocs/DCIM/"
